import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl ="https://gist.githubusercontent.com/Sheela2930/a868c5d9a008e8eeab46c7b64b07411c/raw/65e4a2386c73fb88f8b8332a61b07d71ec283d77/Video_Games.csv";
const width = 950;
const height = 500;
const margin = { top: 20, right: 20, bottom: 50, left: 200 };


const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.sales = +d['NA_Sales'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 12));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 80;
  const innerWidth = width - margin.left - margin.right;
 

  const yScale = scaleBand()
    .domain(data.map(d => d.Name))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.sales)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="red" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.Name}
            x={0}
            y={yScale(d.Name)}
            width={xScale(d.sales)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};

d3.csv('https://gist.githubusercontent.com/Sheela2930/7a5a5f1ab1fa8c52fe9190a9b0d6f835/raw/0fdf9de517895f5297d2a470c81cb77dc07a7b44/Video%2520Games%2520Dataset.csv', function(err, rows){
function unpack(rows, key) {
	return rows.map(function(row)
	{ return row[key]; });}

var trace1 = {
	x:unpack(rows, 'Name'), y: unpack(rows, 'Year'), z: unpack(rows, 'NorthAmerica_Sales'),
	mode: 'markers',
	marker: {
		size: 12,
		line: {
		color: 'rgba(105, 20, 92, 0.1)',
		width: 0.5},
		opacity: 0.9},
	type: 'scatter3d'
};

var trace2 = {
	x:unpack(rows, 'Name'), y: unpack(rows, 'Year'), z: unpack(rows, 'Japan_Sales'),
	mode: 'markers',
	marker: {
		size: 12,
		line: {
		color: 'rgb(252,78,3)',
		width: 1},
		opacity: 0.8},
	type: 'scatter3d'};

var data = [trace1, trace2];
var layout = {
    margin: { l: 0, r: 0, b: 0, t: 0 },
    scene: { zaxis: { title: 'Sales- NA and japan' },yaxis: { title: 'Year' },xaxis: { title: 'Game Names', } }  // added zaxis property with title attribute
  };
Plotly.newPlot('myDiv', data, layout);
});


const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);


